Crate zip_extract
source · [−]Expand description
zip-extract
zip-extract’s primary goal is simple: Automate tedious zip extraction. Ever wanted to just unpack an archive somewhere? Well, here you go:
Usage
See extract for details.
ⓘ
let archive: Vec<u8> = download_my_archive()?;
let target_dir = PathBuf::from("my_target_dir"); // Doesn't need to exist
// The third parameter allows you to strip away toplevel directories.
// If `archive` contained a single folder, that folder's contents would be extracted instead.
zip_extract::extract(Cursor::new(archive), &target_dir, true)?;Features
All features are passed through to zip and flate2. They are:
deflate: Support for the Deflate algorithm (miniz_oxiderust-backend)deflate-miniz: ^ dito (minizC-backend)deflate-zlib: ^ dito (zlibC-backend)bzip2: Support for .bzip2 archives via thebzip2crate
The default is bzip2 and deflate.
Enums
Re-export of zip’s error type, for convenience.
zip-extract’s error type
Functions
Extracts a zip archive into target_dir.